@@ -93,7 +93,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::shipping::FulfillmentTypeSelection;
             use checkout_core::server::IdParam;
             use checkout_core::server::CreateParams;
-            use checkout_core::server::AddOrRemoveItemBodyParams;
+            use checkout_core::server::AddOrRemoveItemParams;
             use checkout_core::transaction::TransactionController;
             use checkout_core::context::Context;
             use checkout_core::context::ContextProvider;
@@ -155,7 +155,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn add_item_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<AddOrRemoveItemBodyParams>,
+                body: TypedBody<AddOrRemoveItemParams>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let path_params = path.into_inner();
                 let body_params = body.into_inner();
@@ -191,7 +191,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn remove_item_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<AddOrRemoveItemBodyParams>,
+                body: TypedBody<AddOrRemoveItemParams>,
             ) -> Result<HttpResponseOk<Checkout>, HttpError> {
                 let path_params = path.into_inner();
                 let body_params = body.into_inner();
@@ -415,7 +415,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 api.register(checkout_server::initiate_payment_endpoint).unwrap();
             }
 
-            fn new_server(
+            async fn new_server(
                 self,
                 bind_address: &str,
             ) -> Result<
